<!DOCTYPE TS><TS>
<context>
    <name>QextScintillaCommand</name>
    <message>
        <source>Move left one character</source>
        <translation>Ein Zeichen nach links</translation>
    </message>
    <message>
        <source>Move right one character</source>
        <translation>Ein Zeichen nach rechts</translation>
    </message>
    <message>
        <source>Move up one line</source>
        <translation>Eine Zeile nach oben</translation>
    </message>
    <message>
        <source>Move down one line</source>
        <translation>Eine Zeile nach unten</translation>
    </message>
    <message>
        <source>Move left one word part</source>
        <translation>Ein Wortteil nach links</translation>
    </message>
    <message>
        <source>Move right one word part</source>
        <translation>Ein Wortteil nach rechts</translation>
    </message>
    <message>
        <source>Move left one word</source>
        <translation>Ein Wort nach links</translation>
    </message>
    <message>
        <source>Move right one word</source>
        <translation>Ein Wort nach rechts</translation>
    </message>
    <message>
        <source>Move to first visible character in line</source>
        <translation>Zum ersten sichtbaren Zeichen</translation>
    </message>
    <message>
        <source>Move to end of line</source>
        <translation>Zum Ende der Zeile</translation>
    </message>
    <message>
        <source>Scroll view down one line</source>
        <translation>Eine Zeile nach unten rollen</translation>
    </message>
    <message>
        <source>Scroll view up one line</source>
        <translation>Eine Zeile nach oben rollen</translation>
    </message>
    <message>
        <source>Move up one page</source>
        <translation>Eine Seite hoch</translation>
    </message>
    <message>
        <source>Move down one page</source>
        <translation>Eine Seite nach unten</translation>
    </message>
    <message>
        <source>Move to start of text</source>
        <translation>Zum Textanfang</translation>
    </message>
    <message>
        <source>Move to end of text</source>
        <translation>Zum Textende</translation>
    </message>
    <message>
        <source>Indent one level</source>
        <translation>Eine Ebene einrücken</translation>
    </message>
    <message>
        <source>Move back one indentation level</source>
        <translation>Eine Ebene ausrücken</translation>
    </message>
    <message>
        <source>Select all text</source>
        <translation>Gesamten Text auswählen</translation>
    </message>
    <message>
        <source>Extend selection left one character</source>
        <translation>Auswahl um ein Zeichen nach links erweitern</translation>
    </message>
    <message>
        <source>Extend selection right one character</source>
        <translation>Auswahl um ein Zeichen nach rechts erweitern</translation>
    </message>
    <message>
        <source>Extend selection up one line</source>
        <translation>Auswahl um eine Zeile nach oben erweitern</translation>
    </message>
    <message>
        <source>Extend selection down one line</source>
        <translation>Auswahl um eine Zeile nach unten erweitern</translation>
    </message>
    <message>
        <source>Extend selection left one word part</source>
        <translation>Auswahl um einen Wortteil nach links erweitern</translation>
    </message>
    <message>
        <source>Extend selection right one word part</source>
        <translation>Auswahl um einen Wortteil nach rechts erweitern</translation>
    </message>
    <message>
        <source>Extend selection left one word</source>
        <translation>Auswahl um ein Wort nach links erweitern</translation>
    </message>
    <message>
        <source>Extend selection right one word</source>
        <translation>Auswahl um ein Wort nach rechts erweitern</translation>
    </message>
    <message>
        <source>Extend selection to first visible character in line</source>
        <translation>Auswahl bis zum ersten sichtbaren Zeichen erweitern</translation>
    </message>
    <message>
        <source>Extend selection to start of line</source>
        <translation>Auswahl bis zum Zeilenanfang erweitern</translation>
    </message>
    <message>
        <source>Extend selection to end of line</source>
        <translation>Auswahl bis zum Zeilenende erweitern</translation>
    </message>
    <message>
        <source>Extend selection up one page</source>
        <translation>Auswahl um eine Seite nach oben erweitern</translation>
    </message>
    <message>
        <source>Extend selection down one page</source>
        <translation>Auswahl um eine Seite nach unten erweitern</translation>
    </message>
    <message>
        <source>Extend selection to start of text</source>
        <translation>Auswahl bis zum Textanfang erweitern</translation>
    </message>
    <message>
        <source>Extend selection to end of text</source>
        <translation>Auswahl bis zum Textende erweitern</translation>
    </message>
    <message>
        <source>Delete previous character</source>
        <translation>Zeichen links löschen</translation>
    </message>
    <message>
        <source>Delete previous character if not at line start</source>
        <translation>Zeichen links löschen, wenn nicht am Zeilenanfang</translation>
    </message>
    <message>
        <source>Delete current character</source>
        <translation>Aktuelles Zeichen löschen</translation>
    </message>
    <message>
        <source>Delete word to left</source>
        <translation>Wort links löschen</translation>
    </message>
    <message>
        <source>Delete word to right</source>
        <translation>Wort rechts löschen</translation>
    </message>
    <message>
        <source>Delete line to left</source>
        <translation>Zeile links löschen</translation>
    </message>
    <message>
        <source>Delete line to right</source>
        <translation>Zeile rechts löschen</translation>
    </message>
    <message>
        <source>Insert new line</source>
        <translation>Neue Zeile einfügen</translation>
    </message>
    <message>
        <source>Delete current line</source>
        <translation>Aktuelle Zeile löschen</translation>
    </message>
    <message>
        <source>Duplicate current line</source>
        <translation>Aktuelle Zeile duplizieren</translation>
    </message>
    <message>
        <source>Swap current and previous lines</source>
        <translation>Aktuelle Zeile mit vorhergehender tauschen</translation>
    </message>
    <message>
        <source>Cut current line</source>
        <translation>Aktuelle Zeile ausschneiden</translation>
    </message>
    <message>
        <source>Cut selection</source>
        <translation>Auswahl ausschneiden</translation>
    </message>
    <message>
        <source>Copy selection</source>
        <translation>Auswahl kopieren</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>Redo last command</source>
        <translation>Letzten Befehl wiederholen</translation>
    </message>
    <message>
        <source>Undo the last command</source>
        <translation>Letzten Befehl rückgängig</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Toggle insert/overtype</source>
        <translation>Einfügen/Überschreiben umschalten</translation>
    </message>
    <message>
        <source>Convert selection to lower case</source>
        <translation>Auswahl in Kleinbuchstaben umwandeln</translation>
    </message>
    <message>
        <source>Convert selection to upper case</source>
        <translation>Auswahl in Großbuchstaben umwandeln</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Vergrößern</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Verkleinern</translation>
    </message>
    <message>
        <source>Move up one paragraph</source>
        <translation>Einen Absatz nach oben</translation>
    </message>
    <message>
        <source>Move down one paragraph</source>
        <translation>Einen Absatz nach unten</translation>
    </message>
    <message>
        <source>Extend selection up one paragraph</source>
        <translation>Auswahl um einen Absatz nach oben erweitern</translation>
    </message>
    <message>
        <source>Extend selection down one paragraph</source>
        <translation>Auswahl um einen Absatz nach unten erweitern</translation>
    </message>
    <message>
        <source>Copy current line</source>
        <translation>Aktuelle Zeile kopieren</translation>
    </message>
    <message>
        <source>Extend rectangular selection down one line</source>
        <translation>Rechteckige Auswahl um eine Zeile nach unten erweitern</translation>
    </message>
    <message>
        <source>Extend rectangular selection up one line</source>
        <translation>Rechteckige Auswahl um eine Zeile nach oben erweitern</translation>
    </message>
    <message>
        <source>Extend rectangular selection left one character</source>
        <translation>Rechteckige Auswahl um ein Zeichen nach links erweitern</translation>
    </message>
    <message>
        <source>Extend rectangular selection right one character</source>
        <translation>Rechteckige Auswahl um ein Zeichen nach rechts erweitern</translation>
    </message>
    <message>
        <source>Move to start of displayed line</source>
        <translation>Zum Beginn der angezeigten Zeile</translation>
    </message>
    <message>
        <source>Extend rectangular selection to first visible character in line</source>
        <translation>Rechteckige Auswahl bis zum ersten sichtbaren Zeichen erweitern</translation>
    </message>
    <message>
        <source>Move to end of displayed line</source>
        <translation>Zum Ende der angezeigten Zeile</translation>
    </message>
    <message>
        <source>Extend selection to end of displayed line</source>
        <translation>Auswahl bis zum Ende der angezeigten Zeile erweitern</translation>
    </message>
    <message>
        <source>Extend rectangular selection to end of line</source>
        <translation>Rechteckige Auswahl bis zum Zeilenende erweitern</translation>
    </message>
    <message>
        <source>Extend rectangular selection up one page</source>
        <translation>Rechteckige Auswahl um eine Seite nach oben erweitern</translation>
    </message>
    <message>
        <source>Extend rectangular selection down one page</source>
        <translation>Rechteckige Auswahl um eine Seite nach unten erweitern</translation>
    </message>
    <message>
        <source>Set zoom</source>
        <translation>Zoom einstellen</translation>
    </message>
    <message>
        <source>Formfeed</source>
        <translation>Seitenumbruch</translation>
    </message>
</context>
<context>
    <name>QextScintillaLexerBash</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Zahl</translation>
    </message>
    <message>
        <source>Keyword</source>
        <translation>Schlüsselwort</translation>
    </message>
    <message>
        <source>Double-quoted string</source>
        <translation>Zeichenkette in Anführungszeichen</translation>
    </message>
    <message>
        <source>Single-quoted string</source>
        <translation>Zeichenkette in Hochkommata</translation>
    </message>
    <message>
        <source>Operator</source>
        <translation>Operator</translation>
    </message>
    <message>
        <source>Identifier</source>
        <translation>Bezeichner</translation>
    </message>
    <message>
        <source>Scalar</source>
        <translation>Skalar</translation>
    </message>
    <message>
        <source>Parameter expansion</source>
        <translation>Parametererweiterung</translation>
    </message>
    <message>
        <source>Backticks</source>
        <translation>Backticks</translation>
    </message>
    <message>
        <source>Here document delimiter</source>
        <translation>Here Dokument-Begrenzer</translation>
    </message>
    <message>
        <source>Single-quoted here document</source>
        <translation>Here Dokument in Hochkommata</translation>
    </message>
</context>
<context>
    <name>QextScintillaLexerBatch</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>Keyword</source>
        <translation>Schlüsselwort</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Marke</translation>
    </message>
    <message>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <source>Operator</source>
        <translation>Operator</translation>
    </message>
    <message>
        <source>Hide command character</source>
        <translation>&quot;Befehl verbergen&quot; Zeichen</translation>
    </message>
    <message>
        <source>External command</source>
        <translation>Externer Befehl</translation>
    </message>
</context>
<context>
    <name>QextScintillaLexerCPP</name>
    <message>
        <source>Number</source>
        <translation>Zahl</translation>
    </message>
    <message>
        <source>Keyword</source>
        <translation>Schlüsselwort</translation>
    </message>
    <message>
        <source>Double-quoted string</source>
        <translation>Zeichenkette in Anführungszeichen</translation>
    </message>
    <message>
        <source>Single-quoted string</source>
        <translation>Zeichenkette in Hochkommata</translation>
    </message>
    <message>
        <source>Pre-processor block</source>
        <translation>Preprozessorblock</translation>
    </message>
    <message>
        <source>Operator</source>
        <translation>Operator</translation>
    </message>
    <message>
        <source>Identifier</source>
        <translation>Bezeichner</translation>
    </message>
    <message>
        <source>Unclosed string</source>
        <translation>Unbeendete Zeichenkette</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>C comment</source>
        <translation>C Kommentar</translation>
    </message>
    <message>
        <source>C++ comment</source>
        <translation>C++ Kommentar</translation>
    </message>
    <message>
        <source>JavaDoc style C comment</source>
        <translation>JavaDoc C Kommentar</translation>
    </message>
    <message>
        <source>JavaDoc style C++ comment</source>
        <translation>JavaDoc C++ Kommentar</translation>
    </message>
    <message>
        <source>JavaDoc keyword</source>
        <translation>JavaDoc Schlüsselwort</translation>
    </message>
    <message>
        <source>JavaDoc keyword error</source>
        <translation>JavaDoc Schlüsselwortfehler</translation>
    </message>
    <message>
        <source>Secondary keywords and identifiers</source>
        <translation>Sekundäre Schlusselwörter und Bezeichner</translation>
    </message>
    <message>
        <source>Global classes and typedefs</source>
        <translation>Globale Klassen und typdefinitionen</translation>
    </message>
</context>
<context>
    <name>QextScintillaLexerCSS</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
    <message>
        <source>Class selector</source>
        <translation>Klassenselektor</translation>
    </message>
    <message>
        <source>Pseudo-class</source>
        <translation>Pseudoklasse</translation>
    </message>
    <message>
        <source>Unknown pseudo-class</source>
        <translation>Unbekannte Pseudoklasse</translation>
    </message>
    <message>
        <source>Operator</source>
        <translation>Operator</translation>
    </message>
    <message>
        <source>CSS1 property</source>
        <translation>CSS1 Eigenschaft</translation>
    </message>
    <message>
        <source>Unknown property</source>
        <translation>Unbekannte Eigenschaft</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Wert</translation>
    </message>
    <message>
        <source>ID selector</source>
        <translation>ID-Selektor</translation>
    </message>
    <message>
        <source>Important</source>
        <translation>Wichtig</translation>
    </message>
    <message>
        <source>@-rule</source>
        <translation>@-Regel</translation>
    </message>
    <message>
        <source>Double-quoted string</source>
        <translation>Zeichenkette in Anführungszeichen</translation>
    </message>
    <message>
        <source>Single-quoted string</source>
        <translation>Zeichenkette in Hochkommata</translation>
    </message>
    <message>
        <source>CSS2 property</source>
        <translation>CSS2 Eigenschaft</translation>
    </message>
    <message>
        <source>Attribute</source>
        <translation>Attribut</translation>
    </message>
</context>
<context>
    <name>QextScintillaLexerCSharp</name>
    <message>
        <source>Verbatim string</source>
        <translation>Uninterpretierte Zeichenkette</translation>
    </message>
</context>
<context>
    <name>QextScintillaLexerDiff</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Befehl</translation>
    </message>
    <message>
        <source>Header</source>
        <translation>Kopfzeilen</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <source>Removed line</source>
        <translation>Entfernte Zeile</translation>
    </message>
    <message>
        <source>Added line</source>
        <translation>Hinzugefügte Zeile</translation>
    </message>
</context>
<context>
    <name>QextScintillaLexerHTML</name>
    <message>
        <source>HTML default</source>
        <translation>HTML Standard</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
    <message>
        <source>Unknown tag</source>
        <translation>Unbekanntes Tag</translation>
    </message>
    <message>
        <source>Attribute</source>
        <translation>Attribut</translation>
    </message>
    <message>
        <source>Unknown attribute</source>
        <translation>Unbekanntes Attribut</translation>
    </message>
    <message>
        <source>HTML number</source>
        <translation>HTML Zahl</translation>
    </message>
    <message>
        <source>HTML double-quoted string</source>
        <translation>HTML Zeichenkette in Anführungszeichen</translation>
    </message>
    <message>
        <source>HTML single-quoted string</source>
        <translation>HTML Zeichenkette in Hochkommata</translation>
    </message>
    <message>
        <source>Other text in a tag</source>
        <translation>Anderer Text in einem Tag</translation>
    </message>
    <message>
        <source>HTML comment</source>
        <translation>HTML Kommentar</translation>
    </message>
    <message>
        <source>Entity</source>
        <translation>Entität</translation>
    </message>
    <message>
        <source>End of a tag</source>
        <translation>Tagende</translation>
    </message>
    <message>
        <source>Start of an XML fragment</source>
        <translation>Beginn eines XML Fragmentes</translation>
    </message>
    <message>
        <source>End of an XML fragment</source>
        <translation>Ende eines XML Fragmentes</translation>
    </message>
    <message>
        <source>Script tag</source>
        <translation>Skript Tag</translation>
    </message>
    <message>
        <source>Start of an ASP fragment with @</source>
        <translation>Beginn eines ASP Fragmentes mit @</translation>
    </message>
    <message>
        <source>Start of an ASP fragment</source>
        <translation>Beginn eines ASP Fragmentes</translation>
    </message>
    <message>
        <source>CDATA</source>
        <translation>CDATA</translation>
    </message>
    <message>
        <source>Start of a PHP fragment</source>
        <translation>Beginn eines PHP Fragmentes</translation>
    </message>
    <message>
        <source>Unquoted HTML value</source>
        <translation>HTML Wert ohne Anführungszeichen</translation>
    </message>
    <message>
        <source>ASP X-Code comment</source>
        <translation>ASP X-Code Kommentar</translation>
    </message>
    <message>
        <source>SGML default</source>
        <translation>SGML Standard</translation>
    </message>
    <message>
        <source>SGML command</source>
        <translation>SGML Befehl</translation>
    </message>
    <message>
        <source>First parameter of an SGML command</source>
        <translation>Erster Parameter eines SGML Befehls</translation>
    </message>
    <message>
        <source>SGML double-quoted string</source>
        <translation>SGML Zeichenkette in Anführungszeichen</translation>
    </message>
    <message>
        <source>SGML single-quoted string</source>
        <translation>SGML Zeichenkette in Hochkommata</translation>
    </message>
    <message>
        <source>SGML error</source>
        <translation>SGML Fehler</translation>
    </message>
    <message>
        <source>SGML special entity</source>
        <translation>SGML Spezielle Entität</translation>
    </message>
    <message>
        <source>SGML comment</source>
        <translation>SGML Kommentar</translation>
    </message>
    <message>
        <source>First parameter comment of an SGML command</source>
        <translation>Kommentar des ersten Parameters eines SGML Befehls</translation>
    </message>
    <message>
        <source>SGML block default</source>
        <translation>SGML Standardblock</translation>
    </message>
    <message>
        <source>Start of a JavaScript fragment</source>
        <translation>Beginn eines JavaScript Fragmentes</translation>
    </message>
    <message>
        <source>JavaScript default</source>
        <translation>JavaScript Standard</translation>
    </message>
    <message>
        <source>JavaScript comment</source>
        <translation>JavaScript Kommentar</translation>
    </message>
    <message>
        <source>JavaScript line comment</source>
        <translation>JavaScript Zeilenkommentar</translation>
    </message>
    <message>
        <source>JavaDoc style JavaScript comment</source>
        <translation>JavaDoc JavaScript Kommentar</translation>
    </message>
    <message>
        <source>JavaScript number</source>
        <translation>JavaScript Zahl</translation>
    </message>
    <message>
        <source>JavaScript word</source>
        <translation>JavaScript Wort</translation>
    </message>
    <message>
        <source>JavaScript keyword</source>
        <translation>JavaScript Schlüsselwort</translation>
    </message>
    <message>
        <source>JavaScript double-quoted string</source>
        <translation>JavaScript Zeichenkette in Anführungszeichen</translation>
    </message>
    <message>
        <source>JavaScript single-quoted string</source>
        <translation>JavaScript Zeichenkette in Hochkommata</translation>
    </message>
    <message>
        <source>JavaScript symbol</source>
        <translation>JavaScript Symbol</translation>
    </message>
    <message>
        <source>JavaScript unclosed string</source>
        <translation>JavaScript Unbeendete Zeichenkette</translation>
    </message>
    <message>
        <source>JavaScript regular expression</source>
        <translation>JavaScript Regulärer Ausdruck</translation>
    </message>
    <message>
        <source>Start of an ASP JavaScript fragment</source>
        <translation>Beginn eines ASP JavaScript Fragmentes</translation>
    </message>
    <message>
        <source>ASP JavaScript default</source>
        <translation>ASP JavaScript Standard</translation>
    </message>
    <message>
        <source>ASP JavaScript comment</source>
        <translation>ASP JavaScript Kommentar</translation>
    </message>
    <message>
        <source>ASP JavaScript line comment</source>
        <translation>ASP JavaScript Zeilenkommentar</translation>
    </message>
    <message>
        <source>JavaDoc style ASP JavaScript comment</source>
        <translation>JavaDoc ASP JavaScript Kommentar</translation>
    </message>
    <message>
        <source>ASP JavaScript number</source>
        <translation>ASP JavaScript Zahl</translation>
    </message>
    <message>
        <source>ASP JavaScript word</source>
        <translation>ASP JavaScript Wort</translation>
    </message>
    <message>
        <source>ASP JavaScript keyword</source>
        <translation>ASP JavaScript Schlüsselwort</translation>
    </message>
    <message>
        <source>ASP JavaScript double-quoted string</source>
        <translation>ASP JavaScript Zeichenkette in Anführungszeichen</translation>
    </message>
    <message>
        <source>ASP JavaScript single-quoted string</source>
        <translation>ASP JavaScript Zeichenkette in Hochkommata</translation>
    </message>
    <message>
        <source>ASP JavaScript symbol</source>
        <translation>ASP JavaScript Symbol</translation>
    </message>
    <message>
        <source>ASP JavaScript unclosed string</source>
        <translation>ASP JavaScript Unbeendete Zeichenkette</translation>
    </message>
    <message>
        <source>ASP JavaScript regular expression</source>
        <translation>ASP JavaScript Regulärer Ausdruck</translation>
    </message>
    <message>
        <source>Start of a VBScript fragment</source>
        <translation>Beginn eines VBScript Fragmentes</translation>
    </message>
    <message>
        <source>VBScript default</source>
        <translation>VBScript Standard</translation>
    </message>
    <message>
        <source>VBScript comment</source>
        <translation>VBScript Kommentar</translation>
    </message>
    <message>
        <source>VBScript number</source>
        <translation>VBScript Zahl</translation>
    </message>
    <message>
        <source>VBScript keyword</source>
        <translation>VBScript Schlüsselwort</translation>
    </message>
    <message>
        <source>VBScript string</source>
        <translation>VBScript Zeichenkette</translation>
    </message>
    <message>
        <source>VBScript identifier</source>
        <translation>VBScript Bezeichner</translation>
    </message>
    <message>
        <source>VBScript unclosed string</source>
        <translation>VBScript Unbeendete Zeichenkette</translation>
    </message>
    <message>
        <source>Start of an ASP VBScript fragment</source>
        <translation>Beginn eines ASP VBScript Fragmentes</translation>
    </message>
    <message>
        <source>ASP VBScript default</source>
        <translation>ASP VBScript Standard</translation>
    </message>
    <message>
        <source>ASP VBScript comment</source>
        <translation>ASP VBScript Kommentar</translation>
    </message>
    <message>
        <source>ASP VBScript number</source>
        <translation>ASP VBScript Zahl</translation>
    </message>
    <message>
        <source>ASP VBScript keyword</source>
        <translation>ASP VBScript Schlüsselwort</translation>
    </message>
    <message>
        <source>ASP VBScript string</source>
        <translation>ASP VBScript Zeichenkette</translation>
    </message>
    <message>
        <source>ASP VBScript identifier</source>
        <translation>ASP VBScript Bezeichner</translation>
    </message>
    <message>
        <source>ASP VBScript unclosed string</source>
        <translation>ASP VBScript Unbeendete Zeichenkette</translation>
    </message>
    <message>
        <source>Start of a Python fragment</source>
        <translation>Beginn eines Python Fragmentes</translation>
    </message>
    <message>
        <source>Python default</source>
        <translation>Python Standard</translation>
    </message>
    <message>
        <source>Python comment</source>
        <translation>Python Kommentar</translation>
    </message>
    <message>
        <source>Python number</source>
        <translation>Python Zahl</translation>
    </message>
    <message>
        <source>Python double-quoted string</source>
        <translation>Python Zeichenkette in Anführungszeichen</translation>
    </message>
    <message>
        <source>Python single-quoted string</source>
        <translation>Python Zeichenkette in Hochkommata</translation>
    </message>
    <message>
        <source>Python keyword</source>
        <translation>Python Schlüsselwort</translation>
    </message>
    <message>
        <source>Python triple double-quoted string</source>
        <translation>Python Zeichenkette in dreifachen Anführungszeichen</translation>
    </message>
    <message>
        <source>Python triple single-quoted string</source>
        <translation>Python Zeichenkette in dreifachen Hochkommata</translation>
    </message>
    <message>
        <source>Python class name</source>
        <translation>Python Klassenname</translation>
    </message>
    <message>
        <source>Python function or method name</source>
        <translation>Python Funktions- oder Methodenname</translation>
    </message>
    <message>
        <source>Python operator</source>
        <translation>Python Operator</translation>
    </message>
    <message>
        <source>Python identifier</source>
        <translation>Python Bezeichner</translation>
    </message>
    <message>
        <source>Start of an ASP Python fragment</source>
        <translation>Beginn eines ASP Python Fragmentes</translation>
    </message>
    <message>
        <source>ASP Python default</source>
        <translation>ASP Python Standard</translation>
    </message>
    <message>
        <source>ASP Python comment</source>
        <translation>ASP Python Kommentar</translation>
    </message>
    <message>
        <source>ASP Python number</source>
        <translation>ASP Python Zahl</translation>
    </message>
    <message>
        <source>ASP Python double-quoted string</source>
        <translation>ASP Python Zeichenkette in Anführungszeichen</translation>
    </message>
    <message>
        <source>ASP Python single-quoted string</source>
        <translation>ASP Python Zeichenkette in Hochkommata</translation>
    </message>
    <message>
        <source>ASP Python keyword</source>
        <translation>ASP Python Schlüsselwort</translation>
    </message>
    <message>
        <source>ASP Python triple double-quoted string</source>
        <translation>ASP Python Zeichenkette in dreifachen Anführungszeichen</translation>
    </message>
    <message>
        <source>ASP Python triple single-quoted string</source>
        <translation>ASP Python Zeichenkette in dreifachen Hochkommata</translation>
    </message>
    <message>
        <source>ASP Python class name</source>
        <translation>ASP Python Klassenname</translation>
    </message>
    <message>
        <source>ASP Python function or method name</source>
        <translation>ASP Python Funktions- oder Methodenname</translation>
    </message>
    <message>
        <source>ASP Python operator</source>
        <translation>ASP Python Operator</translation>
    </message>
    <message>
        <source>ASP Python identifier</source>
        <translation>ASP Python Bezeichner</translation>
    </message>
    <message>
        <source>PHP default</source>
        <translation>PHP Standard</translation>
    </message>
    <message>
        <source>PHP double-quoted string</source>
        <translation>PHP Zeichenkette in Anführungszeichen</translation>
    </message>
    <message>
        <source>PHP single-quoted string</source>
        <translation>PHP Zeichenkette in Hochkommata</translation>
    </message>
    <message>
        <source>PHP keyword</source>
        <translation>PHP Schlüsselwort</translation>
    </message>
    <message>
        <source>PHP number</source>
        <translation>PHP Zahl</translation>
    </message>
    <message>
        <source>PHP comment</source>
        <translation>PHP Kommentar</translation>
    </message>
    <message>
        <source>PHP line comment</source>
        <translation>PHP Zeilenkommentar</translation>
    </message>
    <message>
        <source>PHP double-quoted variable</source>
        <translation>PHP Variable in Anführungszeichen</translation>
    </message>
    <message>
        <source>PHP operator</source>
        <translation>PHP Operator</translation>
    </message>
    <message>
        <source>PHP variable</source>
        <translation>PHP Variable</translation>
    </message>
</context>
<context>
    <name>QextScintillaLexerIDL</name>
    <message>
        <source>UUID</source>
        <translation>UUID</translation>
    </message>
</context>
<context>
    <name>QextScintillaLexerJavaScript</name>
    <message>
        <source>Regular expression</source>
        <translation>Regulärer Ausdruck</translation>
    </message>
</context>
<context>
    <name>QextScintillaLexerLua</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>Line comment</source>
        <translation>Zeilenkommentar</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Zahl</translation>
    </message>
    <message>
        <source>Keyword</source>
        <translation>Schlüsselwort</translation>
    </message>
    <message>
        <source>String</source>
        <translation>Zeichenkette</translation>
    </message>
    <message>
        <source>Character</source>
        <translation>Zeichen</translation>
    </message>
    <message>
        <source>Literal string</source>
        <translation>Uninterpretierte Zeichenkette</translation>
    </message>
    <message>
        <source>Preprocessor</source>
        <translation>Preprozessor</translation>
    </message>
    <message>
        <source>Operator</source>
        <translation>Operator</translation>
    </message>
    <message>
        <source>Identifier</source>
        <translation>Bezeichner</translation>
    </message>
    <message>
        <source>Unclosed string</source>
        <translation>Unbeendete Zeichenkette</translation>
    </message>
    <message>
        <source>Basic functions</source>
        <translation>Basisfunktionen</translation>
    </message>
    <message>
        <source>String, table and maths functions</source>
        <translation>Zeichenketten-, Tabelle- und mathematische Funktionen</translation>
    </message>
    <message>
        <source>Coroutines, i/o and system facilities</source>
        <translation>Koroutinen, I/O- und Systemfunktionen</translation>
    </message>
</context>
<context>
    <name>QextScintillaLexerMakefile</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>Preprocessor</source>
        <translation>Preprozessor</translation>
    </message>
    <message>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <source>Operator</source>
        <translation>Operator</translation>
    </message>
    <message>
        <source>Target</source>
        <translation>Ziel</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
</context>
<context>
    <name>QextScintillaLexerPOV</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>Comment line</source>
        <translation>Kommentarzeile</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Zahl</translation>
    </message>
    <message>
        <source>Operator</source>
        <translation>Operator</translation>
    </message>
    <message>
        <source>Identifier</source>
        <translation>Bezeichner</translation>
    </message>
    <message>
        <source>String</source>
        <translation>Zeichenkette</translation>
    </message>
    <message>
        <source>Unclosed string</source>
        <translation>Unbeendete Zeichenkette</translation>
    </message>
    <message>
        <source>Directive</source>
        <translation>Direktive</translation>
    </message>
    <message>
        <source>Bad directive</source>
        <translation>Ungültige Direktive</translation>
    </message>
    <message>
        <source>Objects, CSG and appearance</source>
        <translation>Objekte, CSG und Erscheinung</translation>
    </message>
    <message>
        <source>Types, modifiers and items</source>
        <translation>Typen, Modifizierer und Items</translation>
    </message>
    <message>
        <source>Predefined identifiers</source>
        <translation>Vordefinierter Bezeichner</translation>
    </message>
    <message>
        <source>Predefined functions</source>
        <translation>Vordefinierte Funktion</translation>
    </message>
    <message>
        <source>User defined 1</source>
        <translation>Nutzerdefiniert 1</translation>
    </message>
    <message>
        <source>User defined 2</source>
        <translation>Nutzerdefiniert 2</translation>
    </message>
    <message>
        <source>User defined 3</source>
        <translation>Nutzerdefiniert 3</translation>
    </message>
</context>
<context>
    <name>QextScintillaLexerPerl</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>POD</source>
        <translation>POD</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Zahl</translation>
    </message>
    <message>
        <source>Keyword</source>
        <translation>Schlüsselwort</translation>
    </message>
    <message>
        <source>Double-quoted string</source>
        <translation>Zeichenkette in Anführungszeichen</translation>
    </message>
    <message>
        <source>Single-quoted string</source>
        <translation>Zeichenkette in Hochkommata</translation>
    </message>
    <message>
        <source>Operator</source>
        <translation>Operator</translation>
    </message>
    <message>
        <source>Identifier</source>
        <translation>Bezeichner</translation>
    </message>
    <message>
        <source>Scalar</source>
        <translation>Skalar</translation>
    </message>
    <message>
        <source>Array</source>
        <translation>Feld</translation>
    </message>
    <message>
        <source>Hash</source>
        <translation>Hash</translation>
    </message>
    <message>
        <source>Symbol table</source>
        <translation>Symboltabelle</translation>
    </message>
    <message>
        <source>Regular expression</source>
        <translation>Regulärer Ausdruck</translation>
    </message>
    <message>
        <source>Substitution</source>
        <translation>Ersetzung</translation>
    </message>
    <message>
        <source>Backticks</source>
        <translation>Backticks</translation>
    </message>
    <message>
        <source>Data section</source>
        <translation>Datensektion</translation>
    </message>
    <message>
        <source>Here document delimiter</source>
        <translation>Here Dokument-Begrenzer</translation>
    </message>
    <message>
        <source>Single-quoted here document</source>
        <translation>Here Dokument in Hochkommata</translation>
    </message>
    <message>
        <source>Double-quoted here document</source>
        <translation>Here Dokument in Anführungszeichen</translation>
    </message>
    <message>
        <source>Backtick here document</source>
        <translation>Here Dokument in Backticks</translation>
    </message>
    <message>
        <source>Quoted string (q)</source>
        <translation>Zeichenkette (q)</translation>
    </message>
    <message>
        <source>Quoted string (qq)</source>
        <translation>Zeichenkette (qq)</translation>
    </message>
    <message>
        <source>Quoted string (qx)</source>
        <translation>Zeichenkette (qx)</translation>
    </message>
    <message>
        <source>Quoted string (qr)</source>
        <translation>Zeichenkette (qr)</translation>
    </message>
    <message>
        <source>Quoted string (qw)</source>
        <translation>Zeichenkette (qw)</translation>
    </message>
    <message>
        <source>POD verbatim</source>
        <translation>POD wörtlich</translation>
    </message>
</context>
<context>
    <name>QextScintillaLexerProperties</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>Section</source>
        <translation>Abschnitt</translation>
    </message>
    <message>
        <source>Assignment</source>
        <translation>Zuweisung</translation>
    </message>
    <message>
        <source>Default value</source>
        <translation>Standardwert</translation>
    </message>
</context>
<context>
    <name>QextScintillaLexerPython</name>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Zahl</translation>
    </message>
    <message>
        <source>Double-quoted string</source>
        <translation>Zeichenkette in Anführungszeichen</translation>
    </message>
    <message>
        <source>Single-quoted string</source>
        <translation>Zeichenkette in Hochkommata</translation>
    </message>
    <message>
        <source>Keyword</source>
        <translation>Schlüsselwort</translation>
    </message>
    <message>
        <source>Triple single-quoted string</source>
        <translation>Zeichenkette in dreifachen Hochkommata</translation>
    </message>
    <message>
        <source>Triple double-quoted string</source>
        <translation>Zeichenkette in dreifachen Anführungszeichen</translation>
    </message>
    <message>
        <source>Class name</source>
        <translation>Klassenname</translation>
    </message>
    <message>
        <source>Function or method name</source>
        <translation>Funktions- oder Methodenname</translation>
    </message>
    <message>
        <source>Operator</source>
        <translation>Operator</translation>
    </message>
    <message>
        <source>Identifier</source>
        <translation>Bezeichner</translation>
    </message>
    <message>
        <source>Comment block</source>
        <translation>Kommentarblock</translation>
    </message>
    <message>
        <source>Unclosed string</source>
        <translation>Unbeendete Zeichenkette</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>QextScintillaLexerRuby</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Zahl</translation>
    </message>
    <message>
        <source>Double-quoted string</source>
        <translation>Zeichenkette in Anführungszeichen</translation>
    </message>
    <message>
        <source>Single-quoted string</source>
        <translation>Zeichenkette in Hochkommata</translation>
    </message>
    <message>
        <source>Keyword</source>
        <translation>Schlüsselwort</translation>
    </message>
    <message>
        <source>Triple double-quoted string</source>
        <translation>Zeichenkette in dreifachen Anführungszeichen</translation>
    </message>
    <message>
        <source>Class name</source>
        <translation>Klassenname</translation>
    </message>
    <message>
        <source>Function or method name</source>
        <translation>Funktions- oder Methodenname</translation>
    </message>
    <message>
        <source>Operator</source>
        <translation>Operator</translation>
    </message>
    <message>
        <source>Identifier</source>
        <translation>Bezeichner</translation>
    </message>
    <message>
        <source>Comment block</source>
        <translation>Kommentarblock</translation>
    </message>
    <message>
        <source>Unclosed string</source>
        <translation>Unbeendete Zeichenkette</translation>
    </message>
</context>
<context>
    <name>QextScintillaLexerSQL</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Zahl</translation>
    </message>
    <message>
        <source>Keyword</source>
        <translation>Schlüsselwort</translation>
    </message>
    <message>
        <source>Single-quoted string</source>
        <translation>Zeichenkette in Hochkommata</translation>
    </message>
    <message>
        <source>Operator</source>
        <translation>Operator</translation>
    </message>
    <message>
        <source>Identifier</source>
        <translation>Bezeichner</translation>
    </message>
    <message>
        <source>Comment line</source>
        <translation>Kommentarzeile</translation>
    </message>
    <message>
        <source>JavaDoc style comment</source>
        <translation>JavaDoc Kommentar</translation>
    </message>
    <message>
        <source>Double-quoted string</source>
        <translation>Zeichenkette in Anführungszeichen</translation>
    </message>
    <message>
        <source>SQL*Plus keyword</source>
        <translation>SQL*Plus Schlüsselwort</translation>
    </message>
    <message>
        <source>SQL*Plus prompt</source>
        <translation>SQL*Plus Eingabe</translation>
    </message>
    <message>
        <source>SQL*Plus comment</source>
        <translation>SQL*Plus Kommentar</translation>
    </message>
    <message>
        <source># comment line</source>
        <translation># Kommentarzeile</translation>
    </message>
    <message>
        <source>JavaDoc keyword</source>
        <translation>JavaDoc Schlüsselwort</translation>
    </message>
    <message>
        <source>JavaDoc keyword error</source>
        <translation>JavaDoc Schlüsselwortfehler</translation>
    </message>
    <message>
        <source>User defined 1</source>
        <translation>Nutzerdefiniert 1</translation>
    </message>
    <message>
        <source>User defined 2</source>
        <translation>Nutzerdefiniert 2</translation>
    </message>
    <message>
        <source>User defined 3</source>
        <translation>Nutzerdefiniert 3</translation>
    </message>
    <message>
        <source>User defined 4</source>
        <translation>Nutzerdefiniert 4</translation>
    </message>
</context>
<context>
    <name>QextScintillaLexerTeX</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Special</source>
        <translation>Spezial</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Gruppe</translation>
    </message>
    <message>
        <source>Symbol</source>
        <translation>Symbol</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Befehl</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
</context>
</TS>
